@@ -1,6 +1,11 @@
 #include "lifecycle.h"
 #include <QDeclarativeView>
 
+#ifdef Q_WS_MAEMO_5
+#include <QDBusConnection>
+#include <QDBusMessage>
+#endif
+
 LifeCycle::LifeCycle(QObject *parent) :
     QObject(parent)
 {
@@ -29,3 +34,14 @@ void LifeCycle::setOrientation(const QString &orient)
     }
 
 }
+
+void LifeCycle::exitAppView()
+{
+#ifdef Q_WS_MAEMO_5
+    QDBusConnection bus = QDBusConnection::sessionBus();
+
+    QDBusMessage message = QDBusMessage::createSignal("/", "com.nokia.hildon_desktop", "exit_app_view");
+        bus.send(message);
+#endif
+
+}
