@@ -4,9 +4,13 @@
 #include <QNetworkProxy>
 #include <QDeclarativeEngine>
 #include <QDeclarativeContext>
-
+#include <QSettings>
 #include "lifecycle.h"
 
+#ifdef HAVE_GLWIDGET
+#include <QGLWidget>
+#endif
+
 //#define THANK_YOU_NOKIA
 
 void setNokesProxy()
@@ -23,8 +27,28 @@ int main(int argc, char *argv[])
 //#ifdef Q_OS_SYMBIAN
 //    QApplication::setGraphicsSystem("openvg");
 //#endif
+
+
+    //QApplication::setGraphicsSystem("raster");
+
+    QSettings s("VilleSoft", "QmlReddit" );
+    QString gs = s.value("startup/graphicssystem", "").toString();
+#ifdef Q_WS_X11
+    gs = "raster";
+#endif
+
+    if (gs == "raster") {
+        QApplication::setGraphicsSystem("raster");
+        //qDebug() << "Using 'raster' graphics system as requested";
+    }
+
     QApplication app(argc, argv);
 
+    QCoreApplication::setOrganizationName("VilleSoft");
+    QCoreApplication::setOrganizationDomain("unknown.domain");
+    QCoreApplication::setApplicationName("QmlReddit");
+
+
     app.setProperty("NoMStyle", true);
 
     //app.setStyle("motif");
@@ -33,7 +57,17 @@ int main(int argc, char *argv[])
     setNokesProxy();
 #endif
 
-    QmlApplicationViewer viewer;
+    QmlApplicationViewer viewer;    
+
+
+
+#ifdef HAVE_GLWIDGET
+    if (gs != "raster") {
+
+        QGLWidget *glWidget = new QGLWidget(&viewer);
+        viewer.setViewport(glWidget);
+    }
+#endif
 
     RedditModel mdl;
     QDeclarativeContext *ctxt = viewer.rootContext();
