@@ -30,9 +30,6 @@ RedditSession::RedditSession(QObject *parent) :
 
 
     m_eng = new QScriptEngine;
-    QCoreApplication::setOrganizationName("VilleSoft");
-    QCoreApplication::setOrganizationDomain("unknown.domain");
-    QCoreApplication::setApplicationName("QmlReddit");
 
     RCookieJar* cj = new RCookieJar(this);
     QSettings s;
@@ -464,4 +461,16 @@ void RedditSession::prepareRequest(QNetworkRequest &req)
     }
 }
 
+void RedditSession::setSwRendering(bool val)
+{
+    QSettings s("VilleSoft", "QmlReddit" );
+    const char* k = "startup/graphicssystem";
+    if (val) {
+        s.setValue(k, "raster");
+    } else {
+        s.setValue(k, "");
+    }
+
+}
+
 
